@@ -14,20 +14,17 @@
 //!
 
 mod line_desc;
-mod plot;
+mod plots;
 mod polynomial;
 mod render;
-mod scatter;
 mod eval;
-mod bar;
 
+pub use plots::*;
 pub use line_desc::*;
-pub use plot::*;
 pub use polynomial::*;
 pub use render::*;
-pub use scatter::*;
 pub use eval::*;
-pub use bar::*;
+
 
 pub type Matrix = Vec<Vec<f64>>;
 
